@@ -7,9 +7,9 @@ import collections
 import warnings
 import textwrap
 
-try:
+try: # pragma: no cover
     from astropy.io import fits
-except:
+except ImportError:
     import pyfits as fits
 
 from . import CPL_recipe
@@ -280,7 +280,8 @@ class Recipe(object):
     @calib.setter
     def calib(self, source = None):
         if isinstance(source, str) or hasattr(source, 'read'):
-            source = esorex.load_sof(source)
+            from .esorex import load_sof
+            source = load_sof(source)
         self._calib = FrameList(self, source) 
 
     @calib.deleter
@@ -345,7 +346,8 @@ class Recipe(object):
     @param.setter
     def param(self, source = None):
         if isinstance(source, str) or hasattr(source, 'read'):
-            source = esorex.load_rc(source)
+            from .esorex import load_rc
+            source = load_rc(source)
         self._param = ParameterList(self, source)
 
     @param.deleter
@@ -407,7 +409,6 @@ class Recipe(object):
             (``threaded = True``) and an exception occurs, this exception is 
             raised whenever result fields are accessed.
         '''
-        tmpfiles = []
         threaded = ndata.get('threaded', self.threaded)
         mtrace = ndata.get('mtrace', self.mtrace)
         loglevel = ndata.get('loglevel')
@@ -451,7 +452,7 @@ class Recipe(object):
     def _exec(self, output_dir, parlist, framelist, runenv,
               input_len, logger, output_format, delete, mtrace):
         try:
-            return Result(self._recipe.frameConfig(), output_dir,
+            return Result(output_dir,
                           self._recipe.run(output_dir, parlist, framelist,
                                            list(runenv.items()), 
                                            logger.logfile, logger.level,
@@ -567,7 +568,7 @@ class Recipe(object):
         libs = [ ]
         path = Recipe.path.split(':') if isinstance(Recipe.path, str) else Recipe.path
         for p in path:
-            for root, dir, files in os.walk(p):
+            for root, d, files in os.walk(p):
                 libs += [ os.path.join(root, f) 
                            for f in files if f.endswith('.so') ]
         return libs
