@@ -3,13 +3,13 @@ import os
 import signal
 import logging
 
-try:
+try: # pragma: no cover
     from astropy.io import fits
-except:
+except ImportError:
     import pyfits as fits
 
 class Result(object):
-    def __init__(self, recipedefs, dir, res, input_len = 0, logger = None, 
+    def __init__(self, directory, res, input_len = 0, logger = None, 
                  output_format = fits.HDUList):
         '''Build an object containing all result frames.
 
@@ -45,7 +45,7 @@ class Result(object):
            more sophisticated. And this is not usable for non-MUSE recipes
            anyway. So, we will skip this to probably some distant future.
         '''
-        self.dir = os.path.abspath(dir)
+        self.dir = os.path.abspath(directory)
         logger.join()
         if res[2][0]:
             raise CplError(res[2][0], res[1], logger)
@@ -142,7 +142,7 @@ class CplError(Exception):
 
        .. seealso:: :class:`cpl.logger.LogList`
 
-    .. attribute:: next
+    .. attribute:: next_error
      
        Next error, or :obj:`None`.
 
@@ -150,7 +150,7 @@ class CplError(Exception):
     def __init__(self, retval, res, logger = None):
         self.retval = retval
         self.log = logger.entries if logger else None
-        self.next = None
+        self.next_error = None
         if not res:
             self.code, self.msg, self.file, self.line, self.function = (
                 None, None, None, None, None)
@@ -158,18 +158,20 @@ class CplError(Exception):
             self.code, self.msg, self.file, self.line, self.function = res[0]
             o = self
             for r in res[1:]:
-                o.next = CplError(retval, [ r ], logger)
-                o = o.next
+                o.next_error = CplError(retval, [ r ], logger)
+                o = o.next_error
     
     def __iter__(self):
-        class Iter:
+        class Iter(object):
             current = self
-            def next(self):
+            def __next__(self):
                 if Iter.current is None:
                     raise StopIteration
                 s = Iter.current
-                Iter.current = Iter.current.next
+                Iter.current = Iter.current.next_error
                 return s
+            def next(self):
+                return self.__next__()
         return Iter()
 
     def __str__(self):
@@ -179,8 +181,8 @@ class CplError(Exception):
             s = "%s (%i) in %s() (%s:%i)" % (self.msg, self.code, 
                                              self.function, self.file, 
                                              self.line) 
-        if self.next:
-            for e in self.next:
+        if self.next_error:
+            for e in self.next_error:
                 s += "\n    %s (%i) in %s() (%s:%i)" % (e.msg, e.code, 
                                                         e.function, e.file, 
                                                         e.line) 
@@ -286,10 +288,10 @@ class RecipeCrash(Exception):
                           for e in self.elements ]
         Exception.__init__(self, str(self))
 
-    def _add_variable(self, vars, line):
+    def _add_variable(self, variables, line):
         s = line.strip().split('=', 1)
         if len(s) > 1:
-            vars[s[0].strip()] = s[1].strip()
+            variables[s[0].strip()] = s[1].strip()
 
     def _parse_function_line(self, line):
         s = line.split()
@@ -317,21 +319,20 @@ class RecipeCrash(Exception):
         log.error('Recipe crashed. Traceback (most recent call last):')
         for e in self.elements:
             logc = logging.getLogger('%s.%s' % (logger.name, e.func))
-            logc.error('  File "%s", %sin %s\n' % (
-                    e.filename, 
-                    'line %i, ' % e.line if e.line else '', 
-                    e.func))
+            logc.error('  File "%s", %sin %s\n',e.filename, 
+                       'line %i, ' % e.line if e.line else '', 
+                       e.func)
             if os.path.exists(e.filename) and e.line:
-                logc.error('    %s\n' 
-                           % open(e.filename).readlines()[e.line-1].strip())
+                logc.error('    %s\n',
+                           open(e.filename).readlines()[e.line-1].strip())
             if e.params:
                 logc.error('  Parameters:')
                 for p, v in e.params.items():
-                    logc.error('    %s = %s' % (p, v))
+                    logc.error('    %s = %s', p, v)
             if e.localvars:
                 logc.error('  Local variables:')
                 for p, v in e.localvars.items():
-                    logc.error('    %s = %s' % (p, v))
+                    logc.error('    %s = %s', p, v)
         log.error(RecipeCrash.signals.get(self.signal, 
                                           '%s: Unknown' % str(self.signal)))
 
