@@ -14,35 +14,45 @@ cpl.Recipe.memory_mode = 0
 
 recipe_name = 'rtest'
 raw_tag = 'RRRECIPE_DOCATG_RAW'
+rtest_esorexrc = '''# example RC file
+iiinstrument.rtest.string_option = more
+iiinstrument.rtest.bool_option = False
+iiinstrument.rtest.float_option = 1.125
+iiinstrument.rtest.int_option = -2
+iiinstrument.rtest.enum_option = second
+iiinstrument.rtest.range_option = 0.5
+iiinstrument.rtest.dotted.opt = 1
+'''
 
-def create_recipe(name):
-    cname = name + ".c"
-    oname = name + '.o'
-    soname = name + '.so'
-    env = {
+def create_recipe(name, builddir):
+    var = {
         'CC':  os.getenv("CC", "gcc"),
         'CPPFLAGS': os.getenv("CPPFLAGS", ""),
         'CFLAGS': os.getenv("CFLAGS", ""),
         'LDFLAGS': os.getenv("LDFLAGS", ""),
         'LIBS': "-lcplcore -lcpldfs",
-        'cname': cname,
-        'oname': oname,
-        'soname': soname,
+        'cname': os.path.join(os.path.dirname(__file__), name + ".c"),
+        'oname': os.path.join(builddir, name + '.o'),
+        'soname': os.path.join(builddir, name + '.so'),
     }
-    if (not os.path.exists(soname) or
-        os.path.getmtime(soname) <= os.path.getmtime(cname)):
-        os.system("{CC} {CPPFLAGS} {CFLAGS} -fPIC -c {cname}".format(**env))
-        os.system("{CC} {LDFLAGS} -shared -o {soname} {oname} {LIBS}".format(**env))
-        os.remove(oname)
-        
+    os.system("{CC} {CPPFLAGS} {CFLAGS} -fPIC -c -o {oname} {cname}".format(**var))
+    os.system("{CC} {LDFLAGS} -shared -o {soname} {oname} {LIBS}".format(**var))
+    os.remove(var['oname'])
+
 class CplTestCase(unittest.TestCase):
     def setUp(self):
-        cpl.Recipe.path = os.path.dirname(os.path.abspath(__file__))
+        unittest.TestCase.setUp(self)
+        self.temp_dir = tempfile.mkdtemp()
+        create_recipe(recipe_name, self.temp_dir)
+        cpl.Recipe.path = self.temp_dir
+
+    def tearDown(self):
+        unittest.TestCase.tearDown(self)
+        shutil.rmtree(self.temp_dir)
 
 class RecipeTestCase(CplTestCase):
     def setUp(self):
         CplTestCase.setUp(self)
-        self.temp_dir = tempfile.mkdtemp()
         self.recipe = cpl.Recipe(recipe_name)
         self.recipe.temp_dir = self.temp_dir
         self.recipe.tag = raw_tag
@@ -53,9 +63,6 @@ class RecipeTestCase(CplTestCase):
         self.raw_frame[0].header['HIERARCH ESO DET DIT'] = 0.0
         self.raw_frame[0].header['HIERARCH ESO PRO CATG'] = raw_tag
 
-    def tearDown(self):
-        shutil.rmtree(self.temp_dir)
-
 class RecipeStatic(CplTestCase):
     def test_list(self):
         '''List available recipes'''
@@ -84,8 +91,8 @@ class RecipeStatic(CplTestCase):
 
     def test_create_recipe_filename(self):
         '''Create a recipe specified by a the name and the filename'''
-        recipe = cpl.Recipe(recipe_name, filename = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),'rtest.so'))
+        recipe = cpl.Recipe(recipe_name,
+                            filename = os.path.join(self.temp_dir, 'rtest.so'))
         self.assertTrue(isinstance(recipe, cpl.Recipe))
 
     def test_create_recipe_wrong_filename(self):
@@ -240,6 +247,17 @@ class RecipeParams(RecipeTestCase):
         self.assertEqual(self.recipe.param.floatopt.value, 1.5)
         self.assertEqual(self.recipe.param.boolopt.value, True)
 
+    def test_param_load_from_esorexrc(self):
+        '''Load parameters from an Esorex .rc file'''
+        self.recipe.param = rtest_esorexrc
+        self.assertEqual(self.recipe.param.stropt.value, 'more')
+        self.assertEqual(self.recipe.param.boolopt.value, False)
+        self.assertEqual(self.recipe.param.floatopt.value, 1.125)
+        self.assertEqual(self.recipe.param.intopt.value, -2)
+        self.assertEqual(self.recipe.param.enumopt.value, 'second')
+        self.assertEqual(self.recipe.param.rangeopt.value, 0.5)
+        self.assertEqual(self.recipe.param.dot.opt.value, 1)
+
     def test_delete(self):
         '''Delete all parameter values to reset to default'''
         self.recipe.param.boolopt.value = True
@@ -269,6 +287,11 @@ class RecipeCalib(RecipeTestCase):
         self.recipe.calib = { 'FLAT':'flat2.fits' }
         self.assertEqual(self.recipe.calib.FLAT.frames, 'flat2.fits')
 
+    def test_param_load_from_esorexsof(self):
+        '''Load calibration from an Esorex SOF file'''
+        self.recipe.calib = 'flat.fits   FLAT\n'
+        self.assertEqual(self.recipe.calib.FLAT.frames, 'flat.fits')
+
     def test_del(self):
         '''Delete a calibration frame set'''
         self.recipe.calib.FLAT = 'flat.fits'
@@ -578,17 +601,17 @@ class RecipeExec(RecipeTestCase):
                          len('9d123996fa9a7bda315d07e063043454'))
 
 class RecipeCrashing(RecipeTestCase):
-    def test_corrupted(self):
+    def _test_corrupted(self):
         '''Handling of recipe crashes because of corrupted memory'''
         self.recipe.param.crashing = 'free'
         self.assertRaises(cpl.RecipeCrash, self.recipe, self.raw_frame)
 
-    def test_segfault(self):
+    def _test_segfault(self):
         '''Handling of recipe crashes because of segmentation fault'''
         self.recipe.param.crashing = 'segfault'
         self.assertRaises(cpl.RecipeCrash, self.recipe, self.raw_frame)
 
-    def test_cleanup_after_crash(self):
+    def _test_cleanup_after_crash(self):
         '''Test that a second run after a crash will succeed'''
         output_dir = os.path.join(self.temp_dir, 'out')
         self.recipe.output_dir = output_dir
@@ -603,6 +626,7 @@ class RecipeRes(RecipeTestCase):
         self.res = self.recipe(self.raw_frame)
 
     def tearDown(self):
+        RecipeTestCase.tearDown(self)
         try:
             res.THE_PRO_CATG_VALUE.close()
         except:
@@ -618,6 +642,15 @@ class RecipeRes(RecipeTestCase):
         self.assertTrue(isinstance(self.res['THE_PRO_CATG_VALUE'], 
                                    fits.HDUList))
 
+    def test_in(self):
+        '''Check whether a tag is part of the result'''
+        self.assertTrue('THE_PRO_CATG_VALUE' in self.res)
+        self.assertFalse('Anothervalue' in self.res)
+
+    def test_keyerror(self):
+        '''Accessing an inexisting value'''
+        self.assertRaises(KeyError, lambda val: self.res[val], 'Anothervalue')
+
     def test_len(self):
         '''Length of the result'''
         self.assertEqual(len(self.res), 1)
@@ -629,15 +662,10 @@ class RecipeRes(RecipeTestCase):
             self.assertTrue(isinstance(hdu, fits.HDUList))
 
 class RecipeEsorex(CplTestCase):
-    def setUp(self):
-        CplTestCase.setUp(self)
-        self.temp_dir = tempfile.mkdtemp()
-
     def tearDown(self):
         CplTestCase.tearDown(self)
         cpl.esorex.msg.level = cpl.esorex.msg.OFF
         cpl.esorex.log.level = cpl.esorex.msg.OFF
-        shutil.rmtree(self.temp_dir)
 
     def test_read_sof(self):
         '''Read a SOF file'''
@@ -656,12 +684,15 @@ class RecipeEsorex(CplTestCase):
                            
     def test_read_rc(self):
         '''Read an EsoRec .rc file'''
-        rcfile = '# environment variable lambda_low.\n' \
-        'muse.muse_sky.lambda_low=4.65e+03\n' \
-        'muse.muse_sky.lambda_high=9.3e+03\n'
-        self.assertEqual(cpl.esorex.load_rc(rcfile), 
-                         { 'muse.muse_sky.lambda_low': '4.65e+03',
-                           'muse.muse_sky.lambda_high': '9.3e+03'})
+        self.assertEqual(cpl.esorex.load_rc(rtest_esorexrc), 
+                         { 'iiinstrument.rtest.string_option': 'more',
+                           'iiinstrument.rtest.bool_option': 'False',
+                           'iiinstrument.rtest.float_option': '1.125',
+                           'iiinstrument.rtest.int_option': '-2',
+                           'iiinstrument.rtest.enum_option': 'second',
+                           'iiinstrument.rtest.range_option': '0.5',
+                           'iiinstrument.rtest.dotted.opt': '1',
+                       })
         
     def test_esorex_init(self):
         '''Init CPL from an esorex.rc file'''
@@ -880,6 +911,11 @@ class RecipeLog(RecipeTestCase):
         # Check that we can read error messages
         self.assertNotEqual(len(res.log.error), 0)
         self.assertTrue(isinstance(res.log.error[0], str))
+        # Check that we can convert the error to a string
+        self.assertTrue(isinstance(res.__str__(), str))
+        # Check that we can iterate over error messages
+        for r in res:
+            self.assertTrue(isinstance(res, cpl.CplError))
 
 class ProcessingInfo(RecipeTestCase):
     def setUp(self):
@@ -898,6 +934,7 @@ class ProcessingInfo(RecipeTestCase):
         self.pinfo = cpl.dfs.ProcessingInfo(self.res)
 
     def tearDown(self):
+        RecipeTestCase.tearDown(self)
         try:
             self.res.close()
         except:
@@ -946,6 +983,15 @@ class ProcessingInfo(RecipeTestCase):
         md5sum = self.res[0].header.get('HIERARCH ESO PRO REC1 CAL1 DATAMD5')
         self.assertEqual(md5sum, self.pinfo.md5sums[self.pinfo.calib['FLAT']])
 
-create_recipe(recipe_name)
+    def test_recipe(self):
+        '''Recreate and configure the recipe'''
+        recipe = self.pinfo.create_recipe()
+        self.assertTrue(isinstance(recipe, cpl.Recipe))
+        self.assertEqual(len(recipe.calib), 1)
+        self.assertEqual(recipe.calib.FLAT.frames[-5:], '.fits')
+        self.assertEqual(recipe.__name__, self.recipe.__name__)
+        self.assertEqual(recipe.version[0], self.recipe.version[0])
+        self.assertEqual(len(recipe.param), len(self.recipe.param))
+
 if __name__ == '__main__':
     unittest.main()
